@@ -753,17 +753,17 @@ def rolling_ensembling(X, w_mat_predictors, w_mat_target, n=252, s=63, model_des
     print('s '+str(s))
     print('model' + model_description)
     for slice_n, slice_s in roll():
-        # # Select X
-        # print('slice_n')
-        # print(slice_n)
-        # print('slice_s')
-        # print(slice_s)
-        # print('roll_d')
-        #print(roll.d)
-        #if roll.d == pd.to_datetime('2019-08-23'):
-        #    print('found')
+        # Select X
+        print('slice_n')
+        print(slice_n)
+        print('slice_s')
+        print(slice_s)
+        print('roll_d')
+        print(roll.d)
+
         sub_X = X_.loc[slice_n].copy()
-        assets = list(X.columns[sub_X.apply(ensemble_process)])
+        #assets = list(X.columns[sub_X.apply(ensemble_process)])
+        assets = list(X.columns)
 
         train_X = w_mat_predictors.loc[slice_n].copy()
         train_y = w_mat_target.loc[slice_n, assets].copy()
