@@ -514,3 +514,18 @@ def roll_sharpe(series, period=252, win=0, cap=True):
 
 def from_ret_to_price(series, initial_price = 1.):
     return initial_price * (1 + series).cumprod()
+
+
+def compute_sharpe(df_ret = None, weights = None, period = 252):
+    print('minimum return date')
+    print(min(df_ret.index))
+    print('maximum return date')
+    print(max(df_ret.index))
+    print('minimum weights date')
+    print(min(weights.index))
+    print('maximum weights date')
+    print(max(weights.index))
+    assert df_ret.shape == df_ret.shape
+    assert sum(weights.columns == df_ret.columns) == weights.shape[1]
+    portfolio = np.cumprod(np.prod(df_ret * weights.values + 1, axis=1))
+    return sharpe(portfolio ,period = period)
\ No newline at end of file
